package model

import (
	"slices"
	"strings"

	"github.com/pocketbase/pocketbase/models"
	"github.com/pocketbase/pocketbase/tools/types"
)

type Events []Event

func (m Events) Contains(event Event) bool {
	return slices.Contains(m, event)
}

type AnonymizedEventDTO struct {
	Day   string         `db:"Day" json:"day"`
	Week  string         `db:"Week" json:"week"`
	Start types.DateTime `db:"start" json:"start"`
	End   types.DateTime `db:"end" json:"end"`
	Rooms string         `db:"Rooms" json:"rooms"`
	Free  bool           `json:"free"`
}

type Event struct {
	UUID       string         `db:"uuid" json:"uuid"`
	Day        string         `db:"Day" json:"day"`
	Week       string         `db:"Week" json:"week"`
	Start      types.DateTime `db:"start" json:"start"`
	End        types.DateTime `db:"end" json:"end"`
	Name       string         `db:"Name" json:"name"`
	EventType  string         `db:"EventType" json:"eventType"`
	Compulsory string         `db:"Compulsory" json:"compulsory"`
	Prof       string         `db:"Prof" json:"prof"`
	Rooms      string         `db:"Rooms" json:"rooms"`
	Notes      string         `db:"Notes" json:"notes"`
	BookedAt   string         `db:"BookedAt" json:"bookedAt"`
	Course     string         `db:"course" json:"course"`
	Semester   string         `db:"semester" json:"semester"`
	models.BaseModel
}

func (e *Event) Equals(event Event) bool {
	return e.Day == event.Day &&
		e.Week == event.Week &&
		e.Start == event.Start &&
		e.End == event.End &&
		e.Name == event.Name &&
		e.Course == event.Course &&
		e.Prof == event.Prof &&
		e.Rooms == event.Rooms &&
		e.EventType == event.EventType
}

func (e *Event) TableName() string {
	return "events"
}

// SetCourse func to set the course and returns the event
func (e *Event) SetCourse(course string) Event {
	e.Course = course
	return *e
}

// Creates an AnonymizedEventDTO from an Event hiding all sensitive data
func (e *Event) AnonymizeEvent() AnonymizedEventDTO {
	return AnonymizedEventDTO{
		Day:   e.Day,
		Week:  e.Week,
		Start: e.Start,
		End:   e.End,
		Rooms: e.Rooms,
		Free:  strings.Contains(strings.ToLower(e.Name), "zur freien verfügung"),
	}
}

func (e *Event) GetName() string {
	return e.Name
}

func (e *Event) SetName(name string) {
	e.Name = name
}
